pub struct ActionUN1 {
pub names: Vec<String>,
pub dan: Vec<TenhouRank>,
pub rate: Vec<f64>,
pub sx: Vec<String>,
}Expand description
Corresponds to initial state of the UN tag.
In the original XML, the initial state and reconnection share the UN tag. However, since user utilize them differently, they are intentionally separated into two.
Fields
names: Vec<String>dan: Vec<TenhouRank>rate: Vec<f64>sx: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ActionUN1
impl<'de> Deserialize<'de> for ActionUN1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more